@@ -1,9 +1,9 @@
 /*****
 *
-* Copyright (C) 2001 Yoann Vandoorselaere <yoann@prelude-ids.org>
-* All Rights Reserved
+* Copyright (C) 2001, 2002, 2003, 2004, 2005 PreludeIDS Technologies. All Rights Reserved.
+* Author: Yoann Vandoorselaere <yoann.v@prelude-ids.com>
 *
-* This file is part of the Prelude program.
+* This file is part of the Prelude library.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -24,6 +24,12 @@
 #ifndef _LIBPRELUDE_PRELUDE_IDENT_H
 #define _LIBPRELUDE_PRELUDE_IDENT_H
 
+#include "prelude-inttypes.h"
+
+#ifdef __cplusplus
+ extern "C" {
+#endif
+         
 typedef struct prelude_ident prelude_ident_t;
 
 uint64_t prelude_ident_inc(prelude_ident_t *ident);
@@ -32,6 +38,10 @@ uint64_t prelude_ident_dec(prelude_ident_t *ident);
 
 void prelude_ident_destroy(prelude_ident_t *ident);
 
-prelude_ident_t *prelude_ident_new(const char *filename);
+int prelude_ident_new(prelude_ident_t **ret);
 
+#ifdef __cplusplus
+ }
+#endif
+         
 #endif /* _LIBPRELUDE_PRELUDE_IDENT_H */
